
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#include <QtCore/QDebug>

#include "InfosUpdater.h"
#include "ImageInfos.h"

#include "DatabaseManager.h"

InfosUpdater::InfosUpdater( QObject *parent ) : QObject(parent),
    m_abort( false ),
    m_isRunning(false)
{
    m_dbm = new DatabaseManager;
}

InfosUpdater::~InfosUpdater()
{
    cancel();
    delete m_dbm;
}

void InfosUpdater::storeInfos( ImageInfos *ii )
{
    m_dbm->storeInfos(ii);
}

void InfosUpdater::removeInfos( const QString &url)
{
    m_dbm->removeInfos(url);
}

void InfosUpdater::check( ImageInfos *ii )
{
    m_iiQueue.append( ii );
    run();
}

void InfosUpdater::check( const QList<ImageInfos *> &list )
{
    m_iiQueue.append( list );
    run();
}

void InfosUpdater::cancel()
{
    m_mutex.lock();
    m_abort = true;
    m_iiQueue.clear();
    m_mutex.unlock();
}

bool InfosUpdater::isRunning()
{
    return m_isRunning;
}

void InfosUpdater::run()
{
    m_abort = false;
    m_isRunning = true;
    bool ok = true;

    while(ok)
    {
        m_mutex.lock();

        if ( m_iiQueue.isEmpty() )
        {
            ok = false;
        }
        else
        {
            ImageInfos *ii = m_iiQueue.dequeue();
            m_dbm->retrieveInfos(ii);
            bool somethingDone = ii->update();

            if (somethingDone)
            {
                m_dbm->storeInfos(ii);
                emit updated(ii);
            }
        }
        m_mutex.unlock();
    }

    m_isRunning = false;
    emit finished();
}

void InfosUpdater::clearCache()
{
    m_dbm->clearDB();
}
