
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _LISTIMAGESMODEL_H_
#define _LISTIMAGESMODEL_H_

#include <QtCore/QAbstractItemModel>
#include <QtGui/QIcon>
#include <QtGui/QImage>
#include <QtCore/QList>
#include <QtCore/QPoint>
#include <QtCore/QSet>

class ImageInfos;
class InfosUpdater;

class ListImagesModel : public QAbstractItemModel
{
    Q_OBJECT

public:

    enum
    {
        MODE_LIST = 0, // not used anymore
        MODE_DETAILS,
        MODE_ICONS
    } typMode;

    enum
    {
        COLUMN_NAME = 0,
        COLUMN_RATE,
        COLUMN_IMAGESIZE,
        COLUMN_FILESIZE,
        COLUMN_USER_ADJUST,
        COLUMN_NB
    } typColumn;

    ListImagesModel( QObject *parent = 0 );
    virtual ~ListImagesModel();

    virtual QModelIndex index ( int row, int column, const QModelIndex & parent = QModelIndex() ) const;
    virtual QModelIndex parent ( const QModelIndex & index ) const;
    virtual int columnCount ( const QModelIndex & parent = QModelIndex() ) const;

    virtual QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const;
    virtual QVariant headerData (int inSection, Qt::Orientation inOrientation, int inRole) const;
    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
    virtual Qt::ItemFlags flags( const QModelIndex &index ) const;

    bool removeRows( int row, int count, const QModelIndex &parent = QModelIndex() );

    void removeRows( const QModelIndexList& indexes );

    int rowCount( const QModelIndex &parent = QModelIndex() ) const;
    int getImageCount() const { return m_filesList.size(); }

    void addImages( const QStringList & list );

    QString getFilename(const QModelIndex &index) const;
    QString getFilename(int) const;
    QPoint getOffset(const QModelIndex &index) const;
    QPoint getOffset(int) const;
    int getRating(int) const;
    int getIndex(const QModelIndex &index) const;
    int getIndex(const QString &filename) const;

    void setDisplayMode(int);
    int getDisplayMode() const { return m_mode; }

    void clear();

    void setLastAppliedRow(int);
    void setLastPreviewedRow(int);

    void resetChache();

    void setScreenNumber(int);

signals:

    void updateInfos(const QList<ImageInfos *> &);
    void storeInfos(ImageInfos *);
    void removeInfos(const QString &);
    void updateFinished();

private slots:

    void refresh (ImageInfos *);

private:

    //QVariant      dataList( const QModelIndex &index, int role = Qt::DisplayRole ) const;
    QVariant dataDetails( const QModelIndex &index, int role = Qt::DisplayRole ) const;
    QVariant dataIcons( const QModelIndex &index, int role = Qt::DisplayRole ) const;

    QPixmap shadoizePixmap(const QImage &pm) const;
    void drawShadow(QPainter* painter, const QRect& rect)  const;
    QPixmap generateFuzzyRect(const QSize& size, const QColor& color, int radius) const;
    ImageInfos * getInfos(const QString &filename);

    QList<ImageInfos *> m_filesList;

    InfosUpdater *m_updater;
    int m_mode;
    mutable QMap<int, QPixmap> m_shadowCache;
    QSet<QString> m_alreadyDefined;
    int m_lastAppliedRow; // last applied wallpaper
    int m_lastPreviewedRow; // last previewed file
    int m_nbScreens;
};

#endif // _LISTIMAGESMODEL_H_
