
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#include "SchedulerConfigWidget.h"

#include "ui_SchedulerConfigWidget.h"

SchedulerConfigWidget::SchedulerConfigWidget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::SchedulerConfigWidgetClass)
{
    ui->setupUi(this);

    // transmit scheduler signals
    connect( &m_scheduler, SIGNAL( newEvent() ), this, SIGNAL( newEvent() ) );
    connect( &m_scheduler, SIGNAL( quit() ), this, SIGNAL( quit() ) );

    updateUI();
}

SchedulerConfigWidget::~SchedulerConfigWidget()
{
    delete ui;
}

void SchedulerConfigWidget::updateUI()
{
    ui->checkBoxStartup->setChecked( m_scheduler.getChangeAtStartup() );
    ui->checkBoxStartupAndQuit->setChecked( m_scheduler.getQuitAfterChange() );
    ui->groupBoxFrequency->setChecked( m_scheduler.getIntervalBetweenChangeMode() );
    ui->radioButtonInterval->setChecked( m_scheduler.getChangeByInterval() );
    ui->radioButtonTimeOfDay->setChecked( !m_scheduler.getChangeByInterval() );
    ui->timeEditInterval->setTime( m_scheduler.getInterval() );
    rebuildTODList();
}

void SchedulerConfigWidget::on_checkBoxStartup_stateChanged ( int state )
{
    m_scheduler.setChangeAtStartup(state);
}

void SchedulerConfigWidget::on_checkBoxStartupAndQuit_stateChanged ( int state )
{
    m_scheduler.setQuitAfterChange(state);
    if (state == Qt::Checked)
        ui->groupBoxFrequency->setChecked(false);
}

void SchedulerConfigWidget::on_groupBoxFrequency_clicked(bool val)
{
    m_scheduler.setIntervalBetweenChangeMode(val);
    emit newState();
}

void SchedulerConfigWidget::on_radioButtonInterval_toggled(bool val)
{
    m_scheduler.setChangeByInterval(val);
}

void SchedulerConfigWidget::on_radioButtonTimeOfDay_toggled(bool /*val*/)
{
}

void SchedulerConfigWidget::on_timeEditInterval_timeChanged(const QTime & time)
{
    m_scheduler.setInterval(time);
}

void SchedulerConfigWidget::on_pushButtonAddTOD_pressed()
{
    if ( m_scheduler.addTOD( ui->timeEditTOD->time() ) )
        rebuildTODList();
}

void SchedulerConfigWidget::on_pushButtonDeleteTOD_pressed()
{
    QList<QListWidgetItem *> items = ui->listWidgetTOD->selectedItems ();

    if ( items.isEmpty() )
        return;

    foreach (QListWidgetItem * item, items)
    {
        m_scheduler.deleteTOD( QTime::fromString(item->text(), "hh:mm:ss") );
    }

    rebuildTODList();
}

void SchedulerConfigWidget::rebuildTODList()
{
    ui->listWidgetTOD->clear();
    const QList<QTime> &list = m_scheduler.getTODList();
    foreach(const QTime &time, list)
    {
        new QListWidgetItem(time.toString(), ui->listWidgetTOD);
    }
}

void SchedulerConfigWidget::setIdle(bool val)
{
    ui->groupBoxProperties->setEnabled(val == false);
    m_scheduler.setIdle(val);
}

void SchedulerConfigWidget::saveSettings()
{
    m_scheduler.saveSettings();
}
