
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _SCREENITEM_H_
#define _SCREENITEM_H_

#include <QtGui/QGraphicsItem>
#include <QtGui/QImage>
#include <QtGui/QGraphicsSceneMouseEvent>

class ScreenItem :  public QGraphicsItem
{
public:

    ScreenItem ( const QSize &size, int num,  QGraphicsItem * parent = 0 );

    QRectF boundingRect() const;

    void setSize(const QSize &size);
    void setNumber(int);

    QSize getRealSize() const {return m_realSize; }
    QSize getRealSizeWithMargins() const;
    QSize getSizeWithMargins() const;
    QSize getSize() const {return m_size; }

    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,QWidget *widget);
    int getNumber() const { return m_screenNum; }

    void setMargings(int top, int bottom, int left, int right);
    void setMargingTop(int val);
    int getMarginTop() const {return m_marginTop; }
    void setMargingBottom(int val);
    int getMarginBottom() const {return m_marginBottom; }
    void setMargingLeft(int val);
    int getMarginLeft() const {return m_marginLeft; }
    void setMargingRight(int val);
    int getMarginRight() const {return m_marginRight; }

    // use margins or not
    void setUseMargins(bool);
    bool getUseMargins(){ return m_useMargins; }

    // draw text or not
    void setDrawText(bool);
    bool getDrawText(){ return m_drawText; }

    QRectF getValidSceneBoundingRect();

    void setImage(const QImage &);
    void updateImage();

    void setOpaque(bool val);

private:

    void drawMargins(QPainter *painter);
    void drawDesktop(QPainter *painter);
    void drawTextEffect(QPainter *painter, const QString &text, const QRectF & rect, int alignment, const QPoint &offset);

    QRectF getPreviewSceneBoundingRect();
    QRectF getPreviewSceneWithMarginsBoundingRect();

    QSize m_realSize;
    QSize m_size;
    int m_screenNum;

    int m_marginLeft;
    int m_marginRight;
    int m_marginTop;
    int m_marginBottom;

    QImage m_image;
    QImage m_cropimage;
    bool m_useMargins;
    bool m_drawText;
    bool m_opaque;
};

#endif // _SCREENITEM_H_
