
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *******************************************************************************/

#ifndef _TCPCLIENT_H_
#define _TCPCLIENT_H_

#include <QtCore/QObject>
#include <QtNetwork/QAbstractSocket>

class QTcpSocket;
class QTimer;
class QFile;
class NetworkMessage;

class TcpClient :
    public QObject
{
    Q_OBJECT

public:

    enum States
    {
        INACTIVE,
        CONNECTING,
        NEGOTIATING,
        SENDING,
        FINISHED
    };

    TcpClient(QObject *parent = 0);

    virtual ~TcpClient();

    void start();
    void restart();
    void stop();
    void sendNetworkMessage(const NetworkMessage &mess);
    void setPort(int val) {m_port = val; }
    void setHost(const QString & val) {m_host = val; }
    QAbstractSocket::SocketState getState() const;

    static QString stateToString(QAbstractSocket::SocketState);

signals:

    void stateChanged ( QAbstractSocket::SocketState socketState );
    void newNetworkMessage(const NetworkMessage &);

private slots:

    void readMessage();
    void onSocketConnected();
    void onSocketError(QAbstractSocket::SocketError);
    void onSocketDisconnected();
    void tryToConnect();

private:

    QTcpSocket *m_socket;
    quint8 m_currentState;
    qint64 m_blockSize;
    QByteArray m_buffer;

    QTimer *m_connectionTimer;
    QString m_host;
    int m_port;
    bool m_tryToConnect;
    QTimer *m_reconnect;
};

#endif // _TCPCLIENT_H_
